@@ -9,7 +9,7 @@ __docformat__ = 'restructuredtext en'
 import os, subprocess, re, sys, sysconfig
 from distutils.spawn import find_executable
 
-from setup import isosx, iswindows, is64bit, islinux, ishaiku
+from setup import isfreebsd, isosx, iswindows, is64bit, islinux, ishaiku
 is64bit
 
 NMAKE = RC = msvc = MT = win_inc = win_lib = None
@@ -84,7 +84,12 @@ pyqt['sip_bin'] = os.environ.get('SIP_BIN', 'sip')
 from PyQt5.QtCore import PYQT_CONFIGURATION
 pyqt['sip_flags'] = PYQT_CONFIGURATION['sip_flags']
 def get_sip_dir():
-    q = os.environ.get('SIP_DIR', os.path.join(sys.prefix, 'share', 'sip') if iswindows else os.path.join(sys.prefix, 'share', 'sip'))
+    if iswindows:
+        q = os.environ.get('SIP_DIR', os.path.join(sys.prefix, 'share', 'sip'))
+    elif isfreebsd:
+        q = os.environ.get('SIP_DIR', os.path.join(sys.prefix, 'share', 'py-sip'))
+    else:
+        q = os.path.join(sys.prefix, 'share', 'sip')
     for x in ('', 'Py2-PyQt5', 'PyQt5', 'sip/PyQt5'):
         base = os.path.join(q, x)
         if os.path.exists(os.path.join(base, 'QtWidgets')):
